<?php

require_once('../libraries/Session.php');

$session = new Session();

define('ABSOLUTE_PATH', realpath(dirname(__FILE__) . '/../') . '/');

$writeable_directories = array(
	ABSOLUTE_PATH . 'config'
);

$writeable_files = array(
	ABSOLUTE_PATH . 'config/database.php'
);

function check_settings() {
	
	global $writeable_directories, $writeable_files;
	
	$error = array();
	
	if (version_compare(PHP_VERSION, '5.2.4', '<=')) {
		
		$error['warning'] = TRUE;
		
	}
	
	if (!extension_loaded('session')) {
		
		$error['warning'] = TRUE;
		
	}
	
	if (!extension_loaded('PDO') || !extension_loaded('pdo_mysql')) {
		
		$error['warning'] = TRUE;
		
	}
	
	if (ini_get('register_globals')) {
		
		$error['warning'] = TRUE;
		
	}
	
	if (ini_get('magic_quotes_gpc')) {
		
		$error['warning'] = TRUE;
		
	}
	
	foreach ($writeable_directories as $value) {
		
		if (!is_writable($value)) {
			
			$error['warning'] = TRUE;
			
		}
		
	}

	foreach ($writeable_files as $value) {
		
		if (!is_writable($value)) {
			
			$error['warning'] = TRUE;
			
		}
		
	}
	
	if (!$error) {
		
		return TRUE;
		
	} else {
	
		return FALSE;
		
	}

}	

if (check_settings()) {
	
	$session->set('step_1', TRUE);
	
}

?>
<!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		
		<title>Live Chat | Installation</title>

		<link href="css/main.css" rel="stylesheet">
		<link href="css/bootstrap.min.css" rel="stylesheet">
	
	</head>
	<body>

		<div class="container">
			
			<div class="row">
				
				<div class="span12">

					<div class="row">
						
						<div class="span4">
							
							<div class="well">
								
								<ul class="nav nav-pills nav-stacked">
									<li class="active"><a>Requirements <i class="icon-chevron-right pull-right"></i></a></li>
									<li><a>Database <i class="icon-chevron-right pull-right"></i></a></li>
									<li><a>Settings <i class="icon-chevron-right pull-right"></i></a></li>
									<li><a>Finished <i class="icon-chevron-right pull-right"></i></a></li>
								</ul>

							</div>
							
						</div>

						<div class="span8">
							
							<div class="well">

								<?php if (!check_settings()): ?>
									<div class="alert alert-error">
										It seems that your server failed to meet the requirements to run the script. 
										Please contact your server administrator or hosting company to get this resolved.
									</div>
								<?php endif; ?>

								<table class="table">
									<thead>
										<tr>
											<th>System check</th>
											<th>&nbsp;</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td>PHP Version 5.2.4 or higher</td>
											<td><span class="pull-right"><?php echo PHP_VERSION; ?></span></td>
										</tr>
										<tr>
											<td>Session Support</td>
											<td>
											<?php if (extension_loaded('session')): ?>
												<span class="label label-success pull-right">Success</span>
											<?php else: ?>
												<span class="label label-important pull-right">Failed</span>
											<?php endif; ?>
											</td>
										</tr>
										<tr>
											<td>Register Globals Off</td>
											<td>
											<?php if (!ini_get('register_globals')): ?>
												<span class="label label-success pull-right">Success</span>
											<?php else: ?>
												<span class="label label-important pull-right">Failed</span>
											<?php endif; ?>
											</td>
										</tr>
										<tr>
											<td>Magic Quotes GPC Off</td>
											<td>
											<?php if (!ini_get('magic_quotes_gpc')): ?>
												<span class="label label-success pull-right">Success</span>
											<?php else: ?>
												<span class="label label-important pull-right">Failed</span>
											<?php endif; ?>
											</td>
										</tr>
										<tr>
											<td>PDO Support (MySQL)</td>
											<td>
											<?php if (extension_loaded('PDO') || extension_loaded('pdo_mysql')): ?>
												<span class="label label-success pull-right">Success</span>
											<?php else: ?>
												<span class="label label-important pull-right">Failed</span>
											<?php endif; ?>
											</td>
										</tr>
									</tbody>
								</table>
								
								<table class="table">
									<thead>
										<tr>
											<th>Write permissions on files and folders</th>
											<th>&nbsp;</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td><?php echo 'config/'; ?></td>
											<td>
											<?php if (is_writable(ABSOLUTE_PATH . 'config')): ?>
												<span class="label label-success pull-right">Writable</span>
											<?php else: ?>
												<span class="label label-important pull-right">Unwritable</span>
											<?php endif; ?>
											</td>
										</tr>
										<tr>
											<td><?php echo 'config/database.php'; ?></td>
											<td>
											<?php if (is_writable(ABSOLUTE_PATH . 'config/database.php')): ?>
												<span class="label label-success pull-right">Writable</span>
											<?php else: ?>
												<span class="label label-important pull-right">Unwritable</span>
											<?php endif; ?>
											</td>
										</tr>
									</tbody>
								</table>

								<?php if (check_settings()): ?>
									<a href="step_1.php" class="btn btn-primary">Next step</a>
								<?php else: ?>
									<a href="index.php" class="btn btn-primary">Try again</a>
								<?php endif; ?>

							</div>

						</div>
				
					</div>
					
				</div>

			</div>
			
		</div>

		<div class="navbar navbar-fixed-bottom">
			
			<div class="container">

				<p><small><a href="http://www.gntstudio.eu" target="_blank">Gnt Studio</a></small></p>

			</div>
			
		</div>
		
	</body>
</html>
